@@ -1,13 +1,8 @@
-
 from PyObjCTools.TestSupport import *
 from InputMethodKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
 
-class TestIMKCandidates (TestCase):
+class TestIMKCandidates(TestCase):
     def testConstants(self):
         self.assertEqual(kIMKSingleColumnScrollingCandidatePanel, 1)
         self.assertEqual(kIMKScrollingGridCandidatePanel, 2)
@@ -18,9 +13,13 @@ class TestIMKCandidates (TestCase):
         self.assertEqual(kIMKLocateCandidatesLeftHint, 3)
         self.assertEqual(kIMKLocateCandidatesRightHint, 4)
 
+        self.assertEqual(kIMKMain, 0)
+        self.assertEqual(kIMKAnnotation, 1)
+        self.assertEqual(kIMKSubList, 2)
+
         self.assertIsInstance(IMKCandidatesOpacityAttributeName, unicode)
 
-    @min_os_level('10.6')
+    @min_os_level("10.6")
     def testConstants10_6(self):
         self.assertIsInstance(IMKCandidatesSendServerKeyEventFirst, unicode)
 
@@ -29,7 +28,7 @@ class TestIMKCandidates (TestCase):
         self.assertResultIsBOOL(IMKCandidates.dismissesAutomatically)
         self.assertArgIsBOOL(IMKCandidates.setDismissesAutomatically_, 0)
 
-    @min_os_level('10.7')
+    @min_os_level("10.7")
     def testMethods10_7(self):
         self.assertResultIsBOOL(IMKCandidates.selectCandidateWithIdentifier_)
 
